Script to change permissions and owner recursivily from current directory

Source code & Development:
    https://github.com/Turulomio/recpermissions

Doxygen documentation:
    http://turulomio.users.sourceforge.net/doxygen/recpermissions/

Main developer web page:
    http://turulomio.users.sourceforge.net/en/proyectos.html
    
Pypi web page:
    https://pypi.org/project/recpermissions/

Gentoo ebuild
    You can find a Gentoo ebuild in https://sourceforge.net/p/xulpymoney/code/HEAD/tree/myportage/app-admin/recpermissions/

Usage
=====
You can find use examples in https://github.com/Turulomio/recpermissions/wiki

License
=======
GPL-3

Dependencies
============
* https://www.python.org/, as the main programming language.
* https://pypi.org/project/colorama/, to give console colors.

Changelog
=========
0.2.0
  * Added absolute path parameter to avoid errors and wrong changes

0.1.1
  * Solved bug in current path directory

0.1.0
  * Creating infrastructure
